[toc]



## 简介
基于 Python 的新浪微博图床实现。


## 安装





## 使用


```py
>>> weibo_picbed.upload_screenshot_to_weibo()
False, 'no imgs in clipboard!')
```


## 参考
- https://github.com/suxiaogang/WeiboPicBed



